==> owncloud_7.0.0~rc1%2Bdfsg.orig.tar.bz2: owncloud/apps/activity/l10n/ast.php <==
<?php
$TRANSLATIONS = array(
"Your settings have been updated." => "Anováronse los tos axustes.",
"Activity" => "Actividá",
"A file or folder has been <strong>shared</strong>" => "<strong>Compartióse</strong> un ficheru o direutoriu",
"A new file or folder has been <strong>created</strong> in a shared folder" => "<strong>Creóse</strong> un ficheru o direutoriu nun direutoriu compartíu",
"A file or folder has been <strong>changed</strong> in a shared folder" => "<strong>Camudóse</strong> un ficheru o un direutoriu nun direutoriu compartíu",
"A file or folder has been <strong>deleted</strong> from a shared folder" => "<strong>Desanicióse</strong> un ficheru o direutoriu d'un direutoriu compartíu",
"You created %1\$s" => "Creasti %1\$s",
"%2\$s created %1\$s" => "%2\$s creó %1\$s",
"You changed %1\$s" => "Modificasti %1\$s",
"%2\$s changed %1\$s" => "%2\$s modificó %1\$s",
"You deleted %1\$s" => "Desaniciasti %1\$s",
"%2\$s deleted %1\$s" => "%2\$s desanició %1\$s",
"You shared %1\$s with %2\$s" => "Compartisti %1\$s con %2\$s",
"You shared %1\$s with group %2\$s" => "Compartisti %1\$s col grupu %2\$s",
"%2\$s shared %1\$s with you" => "%2\$s compartió %1\$s contigo",
"You shared %1\$s via link" => "Compartisti %1\$s per enllaz",
"Activity notification" => "Notificación d'actividá",
"All Activities" => "Toles actividaes",
"Activities by you" => "Actividaes por ti",
"Activities by others" => "Actividaes por otros",
"Shares" => "Comparte",
"Files" => "Ficheros",
"%s and %s" => "%s y %s",
", " => ", ",
"_%s and <strong class=\_tooltip\_ title=\_%s\_>%n more</strong>_::_%s and <strong class=\_tooltip\_ title=\_%s\_>%n more</strong>_" => array("%s y <strong class=\"tooltip\" title=\"%s\">%n más</strong>","%s y <strong class=\"tooltip\" title=\"%s\">%n más</strong>"),
"_%s and %n more_::_%s and %n more_" => array("%s y %n más","%s y %n más"),
"Hello %s," => "Hola %s,",
"You are receiving this email because in the last hour the following things happened at %s" => "Tas recibiendo esti corréu porque na cabera hora asocedieron les siguientes coses en %s",
"You are receiving this email because in the last day the following things happened at %s" => "Tas recibiendo esti corréu porque nel caberu día asocedieron les siguientes coses en %s",
"You are receiving this email because in the last week the following things happened at %s" => "Tas recibiendo esti corréu porque na cabera selmana asocedieron les siguientes coses en %s",
"* %s" => "* %s",
"You will see a list of events here when you start to use your %s." => "Vas ver una llista d'eventos equí cuando entames a usar %s.",
"No more events to load" => "Nun hai eventos a cargar",
"Enable RSS feed" => "Habilitar feed RSS",
"Notifications" => "Notificaciones",
"Mail" => "Corréu",
"Stream" => "Fluxu de rede",
"You need to set up your email address before you can receive notification emails." => "Necesites configurar la to direición de corréu enantes que puedas recibir correos de notificación",
"Send emails:" => "Unviar correos:",
"Hourly" => "Cada hora",
"Daily" => "Caldía",
"Weekly" => "Selmanalmente",
"Activity feed" => "Feed d'actividá",
"Personal activity feed for %s" => "Feed d'actividá personal pa %s"
);
$PLURAL_FORMS = "nplurals=2; plural=(n != 1);";

==> owncloud_7.0.1~rc1%2Bdfsg.orig.tar.bz2: owncloud/apps/activity/l10n/ast.php <==
<?php
$TRANSLATIONS = array(
"Your settings have been updated." => "Anováronse los tos axustes.",
"Activity" => "Actividá",
"A file or folder has been <strong>shared</strong>" => "<strong>Compartióse</strong> un ficheru o direutoriu",
"A new file or folder has been <strong>created</strong>" => "<strong>Creóse</strong> un ficheru o carpeta nuevos",
"A file or folder has been <strong>changed</strong>" => "<strong>Camudóse</strong> un ficheru o carpeta",
"A file or folder has been <strong>deleted</strong>" => "<strong>Desanicióse</strong> un ficheru o carpeta",
"You created %1\$s" => "Creasti %1\$s",
"%2\$s created %1\$s" => "%2\$s creó %1\$s",
"You changed %1\$s" => "Modificasti %1\$s",
"%2\$s changed %1\$s" => "%2\$s modificó %1\$s",
"You deleted %1\$s" => "Desaniciasti %1\$s",
"%2\$s deleted %1\$s" => "%2\$s desanició %1\$s",
"You shared %1\$s with %2\$s" => "Compartisti %1\$s con %2\$s",
"You shared %1\$s with group %2\$s" => "Compartisti %1\$s col grupu %2\$s",
"%2\$s shared %1\$s with you" => "%2\$s compartió %1\$s contigo",
"You shared %1\$s via link" => "Compartisti %1\$s per enllaz",
"Activity notification" => "Notificación d'actividá",
"All Activities" => "Toles actividaes",
"Activities by you" => "Actividaes propies",
"Activities by others" => "Actividaes d'otros",
"Shares" => "Comparticiones",
"Files" => "Ficheros",
"%s and %s" => "%s y %s",
", " => ", ",
"_%s and <strong class=\_tooltip\_ title=\_%s\_>%n more</strong>_::_%s and <strong class=\_tooltip\_ title=\_%s\_>%n more</strong>_" => array("%s y <strong class=\"tooltip\" title=\"%s\">%n más</strong>","%s y <strong class=\"tooltip\" title=\"%s\">%n más</strong>"),
"_%s and %n more_::_%s and %n more_" => array("%s y %n más","%s y %n más"),
"Hello %s," => "Hola %s,",
"You are receiving this email because in the last hour the following things happened at %s" => "Tas recibiendo esti corréu porque na cabera hora asocedieron les siguientes coses en %s",
"You are receiving this email because in the last day the following things happened at %s" => "Tas recibiendo esti corréu porque nel caberu día asocedieron les siguientes coses en %s",
"You are receiving this email because in the last week the following things happened at %s" => "Tas recibiendo esti corréu porque na cabera selmana asocedieron les siguientes coses en %s",
"* %s" => "* %s",
"You will see a list of events here when you start to use your %s." => "Vas ver una llista d'eventos equí cuando entames a usar %s.",
"No more events to load" => "Nun hai eventos a cargar",
"Enable RSS feed" => "Habilitar feed RSS",
"Notifications" => "Notificaciones",
"Mail" => "Corréu",
"Stream" => "Fluxu de rede",
"Notify about my own actions" => "Notificar tocante a los mios propios contautos",
"You need to set up your email address before you can receive notification emails." => "Necesites configurar la to direición de corréu enantes que puedas recibir correos de notificación",
"Send emails:" => "Unviar correos:",
"Hourly" => "Cada hora",
"Daily" => "Caldía",
"Weekly" => "Selmanalmente",
"Activity feed" => "Feed d'actividá",
"Personal activity feed for %s" => "Feed d'actividá personal pa %s"
);
$PLURAL_FORMS = "nplurals=2; plural=(n != 1);";
